pub struct ExecutingDescriptor {
pub timestamp: u64,
pub timeout: Option<u64>,
pub chain_id: Option<ChainId>,
}Expand description
An ExecutingDescriptor is a part of the payload to supervisor_checkAccessList
Spec: https://github.com/ethereum-optimism/specs/blob/main/specs/interop/supervisor.md#executingdescriptor
Fields
timestamp: u64The timestamp used to enforce timestamp invariant
timeout: Option<u64>The timeout that requests verification to still hold at timestamp+timeout
(message expiry may drop previously valid messages).
chain_id: Option<ChainId>Chain ID of the chain that the message was executed on.
Implementations